@@ -5,6 +5,11 @@ from datetime import timedelta
 
 import requests
 
+from datetime import datetime, timedelta
+
+import logging
+#from logger import get_logger
+
 this = sys.modules[__name__]
 
 this._GLOBAL_access_token = None
@@ -39,7 +44,7 @@ def configfile(filename):
         pass
 
     else:
-        print("JSON File wrong config")
+        logging.error("JSON File wrong config")
         sys.exit(0)
 
     if "start" in config_json:
@@ -84,12 +89,12 @@ def load_config(IONFile):
     with open(IONFile) as json_file:
         data = json.load(json_file)
         if "ti" not in data:
-            print("Error in ION file - ti")
+            logging.info("Error in ION file - ti")            
             sys.exit(0)
         else:
             this._GLOBAL_ti = data["ti"]
         if "cn" not in data:
-            print("Error in ION file - cn")
+            logging.info("Error in ION file - cn")            
             sys.exit(0)
         else:
             this._GLOBAL_cn = data["cn"]
@@ -194,9 +199,9 @@ def reconnect():
     r = r.json()
     # print (r)
 
-    this._GLOBAL_session_expire = addSecs(start_session, r["expires_in"])
-    if "access_token" not in r:
-        print("Error Reconnect Json")
+    this._GLOBAL_session_expire = addSecs(start_session, r['expires_in'])
+    if 'access_token' not in r:
+        logging.info('Error Reconnect Json')
         sys.exit(0)
     else:
         this._GLOBAL_access_token = r["access_token"]
